function d_o_Tripod = dopen_Tripods(R,RP,wordlength)

    %%%compute all open double open tripds. A dopen Tripod consists of
    %%%the following data: [rp1, rp2, 0, 0] where rp1 = [r11,s11,r12,s12]
    %%% and rp2 = [rp21,s21,r22,s22].
    
    %%%We want that r21,s21 = r12,s12 and that
    %%%the rectangle r11 with orientation s11 is followed by
    %%%r22 with orientation s22.
    
    %%%%a flip of the rectangle pair rpi = [ri1,si1,ri2,si2] is the
    %%%%rectangle pair -[ri2,si2,ri1,si1]. 

    
    d_o_Tripod = [0,0,0,0];
    
    s_l_rp = size(RP);
    Number_RP = s_l_rp(1);
    s_l_rect = size(R);
    Number_R = s_l_rect(1);
    for rp1=1:Number_RP
        for sign_rp1 = -1:2:1
            %%%choose the sign for the rectangle pair 1
            
            if sign_rp1 == -1
                rp_1_temp = rectangle_pair_flip(RP(rp1,:));
            else 
                rp_1_temp = RP(rp1,:);
            end
            
        for rp2=rp1:Number_RP
        for sign_rp2 = -1:2:1
            %%%choose the sign for the rectangle pair 2
            
            if sign_rp2 == -1
                rp_2_temp = rectangle_pair_flip(RP(rp2,:));
            else 
                rp_2_temp = RP(rp2,:);
            end
            
            %%%read off the information of rectangle pair 1
            rp_1_r1 = R(rp_1_temp(1),:);
            rp_1_s1 = rp_1_temp(2);
            rp_1_r2 = R(rp_1_temp(3),:);
            rp_1_s2 = rp_1_temp(4);            
            %%%read off the information of rectangle pair 2
            rp_2_r1 = R(rp_2_temp(1),:);
            rp_2_s1 = rp_2_temp(2);
            rp_2_r2 = R(rp_2_temp(3),:);
            rp_2_s2 = rp_2_temp(4);
            
            %%%%check conditions
            if rp_1_temp(3) == rp_2_temp(1) && rp_1_s2 == rp_2_s1
                if following_rectangle(rp_1_r1,rp_1_s1,rp_2_r2,rp_2_s2, wordlength)==1
                    d_o_Tripod = [d_o_Tripod; sign_rp1*rp1, sign_rp2*rp2,0,0];
                end
            end
            end
        end
    end
    end
d_o_Tripod = d_o_Tripod(2:end,:);
end